#
# spec file for package python-limnoria
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define appname limnoria
%define srcver 2019-02-23
Name:           python-limnoria
Version:        2019.02.23
Release:        lp150.2.1
Summary:        A modified version of Supybot (an IRC bot and framework)
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/ProgVal/Limnoria
Source:         https://github.com/ProgVal/Limnoria/archive/master-%{srcver}.tar.gz
BuildRequires:  %{python_module PySocks}
BuildRequires:  %{python_module SQLAlchemy}
BuildRequires:  %{python_module chardet}
BuildRequires:  %{python_module ecdsa}
BuildRequires:  %{python_module feedparser}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module python-gnupg}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PySocks
Requires:       python-SQLAlchemy
Requires:       python-chardet
Requires:       python-ecdsa
Requires:       python-feedparser
Requires:       python-python-dateutil
Requires:       python-python-gnupg
Requires:       python-pytz
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       Supybot = %{version}
Obsoletes:      Supybot < 1.0
BuildArch:      noarch
%python_subpackages

%description
Limnoria is a Python IRC bot with a plugin API. It is equipped with
an ACL system for specifying user permissions with per-command
granularity. Numerous plugins are included.

%prep
%setup -q -n Limnoria-master-%{srcver}
sed -i "1,4{/\/usr\/bin\/python/d}" plugins/Debug/plugin.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/supybot/
%python_clone -a %{buildroot}%{_mandir}/man1/supybot.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-adduser.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-botchk.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-plugin-create.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-plugin-doc.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-test.1
%python_clone -a %{buildroot}%{_mandir}/man1/supybot-wizard.1
%python_clone -a %{buildroot}%{_bindir}/supybot
%python_clone -a %{buildroot}%{_bindir}/supybot-adduser
%python_clone -a %{buildroot}%{_bindir}/supybot-botchk
%python_clone -a %{buildroot}%{_bindir}/supybot-plugin-create
%python_clone -a %{buildroot}%{_bindir}/supybot-plugin-doc
%python_clone -a %{buildroot}%{_bindir}/supybot-reset-password
%python_clone -a %{buildroot}%{_bindir}/supybot-test
%python_clone -a %{buildroot}%{_bindir}/supybot-wizard

%check
%{python_expand export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{buildroot}%{$python_sitelib}/
%python_exec test/test.py
}

%post
%{python_install_alternative supybot supybot-adduser supybot-botchk
  supybot-plugin-create supybot-plugin-doc supybot-reset-password supybot-test supybot-wizard
  supybot.1 supybot-adduser.1 supybot-botchk.1 supybot-plugin-create.1
  supybot-plugin-doc.1 supybot-test.1 supybot-wizard.1
}

%postun
%{python_uninstall_alternative supybot}

%files %{python_files}
%doc README.md CONTRIBUTING.md
%license LICENSE.md
%python_alternative %{_bindir}/supybot
%python_alternative %{_bindir}/supybot-adduser
%python_alternative %{_bindir}/supybot-botchk
%python_alternative %{_bindir}/supybot-plugin-create
%python_alternative %{_bindir}/supybot-plugin-doc
%python_alternative %{_bindir}/supybot-reset-password
%python_alternative %{_bindir}/supybot-test
%python_alternative %{_bindir}/supybot-wizard
%{python_sitelib}/supybot/
%{python_sitelib}/limnoria-*.egg-info
%python_alternative %{_mandir}/man1/supybot.1
%python_alternative %{_mandir}/man1/supybot-adduser.1
%python_alternative %{_mandir}/man1/supybot-botchk.1
%python_alternative %{_mandir}/man1/supybot-plugin-create.1
%python_alternative %{_mandir}/man1/supybot-plugin-doc.1
%python_alternative %{_mandir}/man1/supybot-test.1
%python_alternative %{_mandir}/man1/supybot-wizard.1

%changelog
* Tue Mar 19 2019 Atri B <badshah400@gmail.com>
- Update to version 2019-02-23:
  * Revert changes to the structure of sdist packages.
  * Fix bugs in wrapping IRC messages.
  * Support for (future) Python 3.8.
  * Fix encoding issue on Python 2.
  * Support [ipv6]:port format.
* Mon Oct 22 2018 badshah400@gmail.com
- Update to version 2018-09-10:
  * Fix Python 3.7 support.
* Tue Aug 28 2018 BArendartchuk@suse.com
- enable Python 2 binaries with update-alternatives: they are
  needed for running legacy plugins
* Fri Aug 17 2018 tchvatal@suse.com
- Drop -devel from deps
* Thu Aug 16 2018 badshah400@gmail.com
- Update to version 2018-06-25-2:
  * test_plugin_create: skip if supybot-plugin-create is not
    installed.
- Changes from version 2018-06-25:
  * Fixes and tests to supybot-plugin-create; modernize the plugin
    template (gh#ProgVal/Limnoria#1340)
  * supybot-plugin-create: compactify import statements in the
    template
  * supybot-plugin-create: prefer importlib over imp on Python >=
    3.4
  * test: add test cases for supybot-plugin-create
  * -plugin-create: fix errors when only a subset of args are
    given
  * -plugin-create: rename --real-name to --author/-a
  * -plugin-create: add -d as an alias to --desc for consistency
* Thu May 10 2018 toddrme2178@gmail.com
- Avoid problem with bytecode being overwritten by tests
* Mon Apr 30 2018 badshah400@gmail.com
- Update to version 2018-04-21:
  * Do not break UTF-8 characters in long words. Closes
    gh#ProgVal/Limnoria#1333.
* Wed Apr 18 2018 badshah400@gmail.com
- The gnupg python module is called python{2,3}-python-gnupg,
  adapt Requires accordingly.
* Fri Apr 13 2018 badshah400@gmail.com
- Switch to using PySocks instead of SocksiPy: the former is
  well-maintained than the latter.
* Sat Mar 31 2018 jengelh@inai.de
- Remove empty filler marketing wording from description.
* Wed Feb 21 2018 badshah400@gmail.com
- Enable python2 module [not binaries] since we have
  python2-SocksiPy now.
* Thu Feb 15 2018 badshah400@gmail.com
- Update to master-2018-01-28:
  * NickAuth: Fix NameError caused by e732931.
* Mon Dec 18 2017 badshah400@gmail.com
- Update to master-2017-10-25:
  * Aka: Escape the command in help strings, so they can be
    copy-pasted into @aka add.
- Convert to python single-spec; disable python2 modules as
  python2-SocksiPy is not available.
- Enable tests as part of %%%%check.
* Fri Nov 25 2016 badshah400@gmail.com
- Initial package.
